@@ -129,7 +129,7 @@ import os, sys, json, time, logging, platform, collections
 from .packages import requests
 from .packages.requests.exceptions import ConnectionError, HTTPError, Timeout
 from .packages.requests.auth import AuthBase
-from .compat import USING_PYTHON2
+from .compat import USING_PYTHON2, expanduser
 
 logger = logging.getLogger(__name__)
 logging.getLogger('dxpy.packages.requests.packages.urllib3.connectionpool').setLevel(logging.ERROR)
@@ -280,8 +280,8 @@ def DXHTTPRequest(resource, data, method='POST', headers=None, auth=True, timeou
     last_error = None
     for retry in range(max_retries + 1):
         streaming_response_truncated = False
+        response = None
         try:
-            response = None
             response = session_handler.request(method, url, data=data, headers=headers, timeout=timeout, auth=auth,
                                                **kwargs)
 
@@ -347,15 +347,31 @@ def DXHTTPRequest(resource, data, method='POST', headers=None, auth=True, timeou
         except _expected_exceptions as e:
             last_error = e
 
-            # TODO: support HTTP/1.1 503 Retry-After
-            # TODO: if the socket was dropped mid-request, ConnectionError or httplib.IncompleteRead is raised,
-            # but non-idempotent requests can be unsafe to retry
-            # Distinguish between connection initiation errors and dropped socket errors
+            if response is not None and response.status_code == 503 and 'retry-after' in response.headers:
+                try:
+                    seconds_to_wait = int(response.headers['retry-after'])
+                except ValueError:
+                    # retry-after could be formatted as absolute time
+                    # instead of seconds to wait. We don't know how to
+                    # parse that, but the apiserver doesn't generate
+                    # such responses anyway.
+                    seconds_to_wait = 60.0
+                logger.warn("%s %s: %s. Waiting %d seconds due to server unavailability..."
+                            % (method, url, str(e), seconds_to_wait))
+                time.sleep(seconds_to_wait)
+                continue
+
+            # TODO: if the socket was dropped mid-request,
+            # ConnectionError or httplib.IncompleteRead is raised, but
+            # non-idempotent requests can be unsafe to retry. We should
+            # distinguish between connection initiation errors and
+            # dropped socket errors. Currently the former are not
+            # retried even if it might be safe to do so.
             if retry < max_retries:
-                if (response is None) or isinstance(e, exceptions.ContentLengthError):
+                if response is None or isinstance(e, exceptions.ContentLengthError) or streaming_response_truncated:
                     ok_to_retry = always_retry or (method == 'GET')
                 else:
-                    ok_to_retry = (response.status_code >= 500 and response.status_code < 600) or streaming_response_truncated
+                    ok_to_retry = 500 <= response.status_code < 600
 
                 if ok_to_retry:
                     if rewind_input_buffer_offset is not None:
@@ -496,7 +512,7 @@ def _initialize(suppress_warning=False):
     '''
     global _DEBUG, _UPGRADE_NOTIFY
     _DEBUG = os.environ.get('_DX_DEBUG', False)
-    _UPGRADE_NOTIFY = os.path.expanduser('~/.dnanexus_config/.upgrade_notify')
+    _UPGRADE_NOTIFY = expanduser('~/.dnanexus_config/.upgrade_notify')
     if os.path.exists(_UPGRADE_NOTIFY) and os.path.getmtime(_UPGRADE_NOTIFY) > time.time() - 86400: # 24 hours
         _UPGRADE_NOTIFY = False
 
